import { colours } from '../../css/colours/';
import { CssClassList } from '../../utilities/css';
import { dialog } from '../../css/dialog/';
import { FontIcon } from '../icons/font-icon';
import { ToolbarItem } from '../app/toolbar';

export interface IDialogProps {
  /**
   * close icon css
   */
  closeIcon?: string;
  /**
   * dialog's header css
   */
  colour?: string;
  /**
   * if set to true, the dialog will occupy the entire screen
   */
  fullSize?: boolean;
  /**
   * Pass a React.Component to the Dialog Footer
   */
  footer?: any;
  /**
   * If set to true, the Dialog Component will be a modal dialog
   */
  modal?: boolean;
  /**
   * Dialog's position
   *  available positions are
   *    bottom
   *    center
   *    top
   * @type {string}
   */
  position: string;
  /**
   * Dialog header's title
   * @type {string}
   */
  title: string;
  /**
   * If set to true, the dialog will be visible
   */
  visible?: boolean;
}

export class Dialog extends React.Component<IDialogProps, {}> {
  public render() {
    let _css = new CssClassList(dialog.dialog);
    let _cssModal = new CssClassList(dialog.overlay.overlay);
    _css.add(dialog[this.props.colour || colours.blue]);
    if (this.props.fullSize) _css.add(dialog.fullSize);
    if (this.props.position && this.props.position.length) _css.add(dialog[this.props.position]);
    if (this.props.visible) _css.add(dialog.visible);
    if (this.props.visible) _cssModal.add(dialog.overlay.visible);
    return (
      <div>
        <section className={_css.toString()}>
          <header className={dialog.dialog__header}>{this.props.title} <FontIcon icon={this.props.closeIcon}/></header>
          <div className={dialog.dialog__content}>{this.props.children}</div>
          {
            this.props.footer ? <footer className={dialog.dialog__footer}>{this.props.footer}</footer> : null
          }
        </section>
        { this.props.modal ? <div className={_cssModal.toString()}></div> : null }
      </div>
    )
  }
}
