import { CssClassList } from '../../utilities/css';
import { colours } from '../../css/colours/';
import { checkbox } from '../../css/form/checkbox/';
import { radio } from '../../css/form/radio/';

export interface ICheckboxProperties {
  /**
   * if set to true, the Component will be checked
   * @optional
   */
  checked?: boolean;
  /**
   * Component colour
   * @optional
   */
  color?: string;
  /**
   * Triggered when the user changes the value (checked/unchecked)
   * @type {Function}
   */
  onChange: any;
  /**
   * HTML name attribute
   * @optional
   */
  name?: string;
  /**
   * HTML type attribute
   *  you can choose between checkbox and radio.
   *  default: checkbox
   * @optional
   */
  type?: string;
  /**
   * Value passed to the onChange callback if not checked
   * @optional
   */
  valueFalse?: any;
  /**
   * Value passed to the onChange callback if checked
   * @optional
   */
  valueTrue?: any;
}

export class Checkbox extends React.Component<ICheckboxProperties, {}> {
  public onchange(event) {
    this.props.onChange(event);
  }

  public render() {
    let _css = new CssClassList(checkbox.checkbox);
    let _inputType = this.props.type === 'checkbox' || this.props.type === 'radio' ? this.props.type : 'checkbox';
    _css.add(checkbox[this.props.color || colours.blue]);
    return (
      <label className={_css.toString()}>
        <input checked={this.props.checked} name={this.props.name} onChange={this.onchange.bind(this)} type={_inputType}/>
        <span>{this.props.children}</span>
      </label>
    )
  }
}

export class Radio extends Checkbox {
  public render() {
    let _css = new CssClassList(radio.radio);
    _css.add(radio[this.props.color || colours.blue]);
    return (
      <label className={_css.toString()}>
        <input checked={this.props.checked} name={this.props.name} onChange={this.onchange.bind(this)} type="radio" value={this.props.checked}/>
        <span>{this.props.children}</span>
      </label>
    )
  }
}
