import { list } from '../../css/lists/';
import { align } from '../../css/text/align/';

export interface IListItemProperties {
  /**
   * if set to true, the list item will be marked as current
   * @type {boolean}
   */
  current?: boolean;
  /**
   * additional className
   * @type {string}
   */
  className?: string;
  /**
   * if set to true, the element will be hidden
   *  default: false
   * @type {boolean}
   */
  hidden?: boolean;
}

class ListItem extends React.Component<IListItemProperties, any> {
  public render() {
    let css = this.props.current ? `${list.list__item.list__item} ${list.list__item.list__item}` : list.list__item.list__item;
    let hidden = this.props.hidden;
    css = this.props.className ? `${css} ${this.props.className}` : css;
    return (
      <li className={css} hidden={hidden}>{this.props.children}</li>
    )
  }
}

export interface IListProperties {
  /**
   * if set to true, the list will be horizontally centered
   *  default: false
   * @type {boolean}
   */
  center?: boolean;
  /**
   * additional css className
   * @type {string}
   */
  className?: string;
  /**
   * if set to true, the Component will be hidden
   *  default: false
   */
  hidden?: boolean;
  /**
   * if set to true, the list will be indented
   *  default: false
   */
  indented?: boolean;
  /**
   * if set to true, the list will not have padding
   *  default: false
   */
  unpadded?: boolean;
  /**
   * if set to true, the list will be vertical
   *  default: false
   */
  vertical?: boolean;
}

export class List extends React.Component<IListProperties, {}> {
  public static Item = ListItem;

  public render() {
    let css = this.props.vertical ? `${list.list} ${list.vertical}` : list.list;
    css = this.props.center && !this.props.vertical ? `${css} ${align.center.xs}` : css;
    css = this.props.indented ? `${css} ${list.indented}` : css;
    css = this.props.unpadded ? `${css} ${list.unpadded}` : css;
    css = this.props.className ? `${css} ${this.props.className}` : css;

    return (
      <ul className={css} hidden={this.props.hidden}>{this.props.children}</ul>
    )
  }
}
