import { CssClassList } from '../../utilities/css';
import { colours } from '../../css/colours/';
import { notification } from '../../css/notifications/notifications/';

export interface INotificationProperties extends INotificationState {
  /**
   * sets the colour for the Notification component
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the notification will be hollow.
   *  default: false
   * @type {boolean}
   */
  hollow?: boolean;
  /**
   * if set to true, the notification will be rounded
   *  default: false
   * @type {boolean}
   */
  rounded?: boolean;
}

export interface INotificationState {
  /**
   * if set to true, the notification will be visible
   */
  visible?: boolean;
}

export class Notification extends React.Component<INotificationProperties, {}> {
  public render() {
    let _css = new CssClassList(notification.notification);
    _css.add(notification[this.props.color || colours.blue]);
    if (this.props.hollow) _css.add(notification.hollow);
    if (this.props.rounded) _css.add(notification.rounded);
    return (
      <div className={_css.toString()} hidden={!this.props.visible}>{this.props.children}</div>
    )
  }
}
