import { colours } from '../../css/colours/';
import { CssClassList } from '../../utilities/css';
import { popup } from '../../css/notifications/popup/';

export interface IPopupProps {
  /**
   * the popup colour
   *  default: blue
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the popup will be modal
   *  @type {boolean}
   */
  modal?: boolean;
  /**
   * if set to true, the popup will be rounded
   *  @type {boolean}
   */
  rounded?: boolean;
  /**
   * sets the text for the popup
   */
  text?: string;
  /**
  * if set to true, the popup will be visible
  *  @type {boolean}
  */
  visible?: boolean;
}

export class Popup extends React.Component<IPopupProps, {}> {
  public render() {
    let _css = new CssClassList(popup.popup);
    _css.add(popup[this.props.color || colours.blue]);
    if (!this.props.visible) _css.add(popup.hidden);
    if (this.props.rounded) _css.add(popup.rounded);
    return (
      <div>
        <div className={_css.toString()}>
          <div className={popup.popup__text}>{this.props.text}</div> {this.props.children}
        </div>
        {
          this.props.modal ? <div className={popup.modal}></div> : null
        }
      </div>
    )
  }
}
